@@ -1,21 +1,18 @@
-from typing import List, Dict, Tuple
+from typing import Dict, List, Tuple
 
+import dash_bootstrap_components as dbc
 import numpy as np
 import pandas as pd
-import dash
-from dash.dependencies import Input, Output, State, ALL
-from dash.exceptions import PreventUpdate
-import dash_core_components as dcc
-import dash_html_components as html
 import webviz_core_components as wcc
-import dash_bootstrap_components as dbc
+from dash import ALL, Dash, Input, Output, State, dcc, html
+from dash.exceptions import PreventUpdate
 from webviz_config.utils import calculate_slider_step
 
 
 class ParameterFilter:
     """Component that can be added to a plugin to filter parameters"""
 
-    def __init__(self, app: dash.Dash, uuid: str, dframe: pd.DataFrame) -> None:
+    def __init__(self, app: Dash, uuid: str, dframe: pd.DataFrame) -> None:
         """
         * **`app`:** The Dash app instance.
         * **`uuid`:** Unique id (use the plugin id).
@@ -137,18 +134,27 @@ class ParameterFilter:
     @property
     def layout(self) -> html.Div:
         return html.Div(
+            style={"height": "100%"},
             children=[
-                html.H4(style={"textAlign": "center"}, children="Parameter filter"),
                 html.Div(
-                    style={"fontSize": "0.8em", "height": "80vh", "overflowY": "auto"},
-                    children=[self._range_sliders, self._discrete_selectors],
+                    style={"height": "90%"},
+                    children=[
+                        wcc.Header(
+                            style={"color": "black"},
+                            children="Parameter filter",
+                        ),
+                        html.Div(
+                            style={"overflowY": "auto", "height": "90%"},
+                            children=[self._range_sliders, self._discrete_selectors],
+                        ),
+                    ],
                 ),
                 self.buttons,
                 dcc.Store(
                     id={"id": self._uuid, "type": "data-store"},
                     data=self._initial_store,
                 ),
-            ]
+            ],
         )
 
     @property
@@ -165,7 +171,11 @@ class ParameterFilter:
             children=[
                 dbc.Button(
                     "Reset",
-                    style={"marginLeft": "10px", "float": "right"},
+                    style={
+                        "width": "48%",
+                        "float": "right",
+                        "background-color": "white",
+                    },
                     className="mr-1",
                     id={"id": self._uuid, "type": "button", "element": "reset"},
                 ),
@@ -173,14 +183,18 @@ class ParameterFilter:
                     "Apply",
                     # style={"padding": "0 20px", "visibility": "hidden"}
                     # if apply_disabled
-                    style={"marginLeft": "10px", "float": "right"},
+                    style={
+                        "width": "48%",
+                        "float": "left",
+                        "background-color": "white",
+                    },
                     className="mr-1",
                     id={"id": self._uuid, "type": "button", "element": "apply"},
                 ),
             ],
         )
 
-    def set_callbacks(self, app: dash.Dash) -> None:
+    def set_callbacks(self, app: Dash) -> None:
         @app.callback(
             Output({"id": self._uuid, "type": "data-store"}, "data"),
             Input({"id": self._uuid, "type": "button", "element": "apply"}, "n_clicks"),
