@@ -1,26 +1,23 @@
-from typing import List, Optional, Dict, Any
-from pathlib import Path
 import warnings
+from pathlib import Path
+from typing import Any, Dict, List, Optional
+
 import numpy as np
 import pandas as pd
-from webviz_subsurface._datainput.fmu_input import find_sens_type
+
 from .ensemble_set_model import EnsembleSetModel
+from .parameter_model import ParametersModel
 
 
 class InplaceVolumesModel:
 
-    SENS_COLUMNS = [
-        "ENSEMBLE",
-        "REAL",
-        "SENSCASE",
-        "SENSNAME",
-        "SENSTYPE",
-    ]
     POSSIBLE_SELECTORS = [
         "FLUID_ZONE",
         "SOURCE",
         "ENSEMBLE",
         "REAL",
+        "FIPNUM",
+        "SET",
         "ZONE",
         "REGION",
         "FACIES",
@@ -47,63 +44,53 @@ class InplaceVolumesModel:
         parameter_table: Optional[pd.DataFrame] = None,
         non_net_facies: Optional[List[str]] = None,
         drop_constants: bool = True,
+        volume_type: str = "static",
     ):
-        self._parameters = []
-        self._sensitivities = []
-        self._sensrun = False
-        self._parameterdf = (
-            parameter_table if parameter_table is not None else pd.DataFrame()
+        self._volume_type = volume_type
+        self.pmodel = ParametersModel(
+            parameter_table, drop_constants=drop_constants, keep_numeric_only=False
         )
         selectors = [x for x in volumes_table.columns if x in self.POSSIBLE_SELECTORS]
 
-        # It is not yet supported to combine sources with different selectors
-        if volumes_table[selectors].isnull().values.any():
-            raise TypeError(
-                f"Selectors {[x for x in selectors if x not in ['ENSEMBLE', 'SOURCE', 'REAL']]} "
-                "needs to be defined for all sources"
+        if volume_type != "dynamic":
+            # compute water zone volumes if total volumes are present
+            if any(col.endswith("_TOTAL") for col in volumes_table.columns):
+                volumes_table = self._compute_water_zone_volumes(
+                    volumes_table, selectors
+                )
+
+            # stack dataframe on fluid zone and add fluid as column istead of a column suffix
+            dfs = []
+            for fluid in ["OIL", "GAS", "WATER"]:
+                fluid_columns = [
+                    x for x in volumes_table.columns if x.endswith(f"_{fluid}")
+                ]
+                if not fluid_columns:
+                    continue
+                df = volumes_table[selectors + fluid_columns].copy()
+                df.columns = df.columns.str.replace(f"_{fluid}", "")
+                df["FLUID_ZONE"] = fluid.lower()
+                dfs.append(df)
+            self._dataframe = pd.concat(dfs)
+
+            # Set NET volumes based on facies if non_net_facies in input
+            if non_net_facies is not None and "FACIES" in self._dataframe:
+                self._dataframe["NET"] = self._dataframe["BULK"]
+                self._dataframe.loc[
+                    self._dataframe["FACIES"].isin(non_net_facies), "NET"
+                ] = 0
+        else:
+            self._dataframe = volumes_table
+            # Workaround the FUID ZONE needs to be defined in the
+            # VolumetricAnalysis plugin - this will be fixed later!
+            self._dataframe["FLUID_ZONE"] = "-"
+
+        # If sensitivity run merge sensitivity columns into the dataframe
+        if self.pmodel.sensrun:
+            self._dataframe = pd.merge(
+                self._dataframe, self.pmodel.sens_df, on=["ENSEMBLE", "REAL"]
             )
 
-        # compute water zone volumes if total volumes are present
-        if any(col.endswith("_TOTAL") for col in volumes_table.columns):
-            volumes_table = self._compute_water_zone_volumes(volumes_table, selectors)
-
-        # stack dataframe on fluid zone and add fluid as column istead of a column suffix
-        dfs = []
-        for fluid in ["OIL", "GAS", "WATER"]:
-            fluid_columns = [
-                x for x in volumes_table.columns if x.endswith(f"_{fluid}")
-            ]
-            if not fluid_columns:
-                continue
-            df = volumes_table[selectors + fluid_columns].copy()
-            df.columns = df.columns.str.replace(f"_{fluid}", "")
-            df["FLUID_ZONE"] = fluid.lower()
-            # Rename PORE to PORV (PORE will be deprecated..)
-            if "PORE" in df:
-                df.rename(columns={"PORE": "PORV"}, inplace=True)
-            dfs.append(df)
-        self._dataframe = pd.concat(dfs)
-
-        # Set NET volumes based on facies if non_net_facies in input
-        if non_net_facies is not None and "FACIES" in self._dataframe:
-            self._dataframe["NET"] = self._dataframe["BULK"]
-            self._dataframe.loc[
-                self._dataframe["FACIES"].isin(non_net_facies), "NET"
-            ] = 0
-
-        # If parameters present check if the case is a sensitivity run
-        # and merge sensitivity columns into the dataframe
-        if parameter_table is not None:
-            self._parameterdf = self._prepare_parameter_data(
-                parameter_table, drop_constants
-            )
-            self._parameters = [
-                x for x in self._parameterdf.columns if x not in self.SENS_COLUMNS
-            ]
-            if "SENSNAME" in self._parameterdf:
-                self._add_sensitivity_columns()
-                self._sensitivities = list(self._dataframe["SENSNAME"].unique())
-
         # set column order
         colorder = self.selectors + self.VOLCOL_ORDER
         self._dataframe = self._dataframe[
@@ -123,15 +110,19 @@ class InplaceVolumesModel:
 
     @property
     def parameter_df(self) -> pd.DataFrame:
-        return self._parameterdf
+        return self.pmodel.dataframe
 
     @property
     def sensrun(self) -> bool:
-        return self._sensrun
+        return self.pmodel.sensrun
+
+    @property
+    def volume_type(self) -> str:
+        return self._volume_type
 
     @property
     def sensitivities(self) -> List[str]:
-        return self._sensitivities
+        return self.pmodel.sensitivities
 
     @property
     def sources(self) -> List[str]:
@@ -161,13 +152,21 @@ class InplaceVolumesModel:
     def selectors(self) -> List[str]:
         return [x for x in self.POSSIBLE_SELECTORS if x in self._dataframe]
 
+    @property
+    def region_selectors(self) -> List[str]:
+        return [
+            x
+            for x in ["FIPNUM", "ZONE", "REGION", "SET", "LICENSE"]
+            if x in self.selectors
+        ]
+
     @property
     def responses(self) -> List[str]:
         return self.volume_columns + self.property_columns
 
     @property
     def parameters(self) -> List[str]:
-        return self._parameters
+        return self.pmodel.parameters
 
     @staticmethod
     def _compute_water_zone_volumes(
@@ -208,7 +207,7 @@ class InplaceVolumesModel:
         if all(col in self._dataframe for col in ["BULK", "PORV"]):
             self._property_columns.append("PORO")
         if all(col in self._dataframe for col in ["NET", "PORV"]):
-            self._property_columns.append("PORO (net)")
+            self._property_columns.append("PORO_NET")
         if all(col in self._dataframe for col in ["HCPV", "PORV"]):
             self._property_columns.append("SW")
 
@@ -217,38 +216,6 @@ class InplaceVolumesModel:
                 pvt = "BO" if vol_column == "STOIIP" else "BG"
                 self._property_columns.append(pvt)
 
-    def _add_sensitivity_columns(self) -> None:
-        """Add sensitivity information columns from the parameters to the
-        dataframe, and raise error if not all ensembles have sensitivity data"""
-
-        self._parameterdf["SENSTYPE"] = self._parameterdf.apply(
-            lambda row: find_sens_type(row.SENSCASE)
-            if not pd.isnull(row.SENSCASE)
-            else np.nan,
-            axis=1,
-        )
-        sens_params_table = self._parameterdf[self.SENS_COLUMNS]
-
-        sensruns = []
-        for _, df in sens_params_table.groupby("ENSEMBLE"):
-            is_sensrun = not df["SENSNAME"].isnull().values.all() and (
-                df["SENSNAME"].nunique() > 1
-                or (df["SENSNAME"].nunique() == 1 and df["SENSTYPE"].unique() != ["mc"])
-            )
-            sensruns.append(is_sensrun)
-        self._sensrun = all(sensruns)
-
-        # raise error if mixed ensemble types
-        if not self._sensrun and any(sensruns):
-            raise ValueError(
-                "Ensembles with and without sensitivity data mixed - this is not supported"
-            )
-
-        # Merge into one dataframe
-        self._dataframe = pd.merge(
-            self._dataframe, sens_params_table, on=["ENSEMBLE", "REAL"]
-        )
-
     def compute_property_columns(
         self, dframe: pd.DataFrame, properties: Optional[list] = None
     ) -> pd.DataFrame:
@@ -261,7 +228,7 @@ class InplaceVolumesModel:
             dframe["NTG"] = dframe["NET"] / dframe["BULK"]
         if "PORO" in properties:
             if "NET" in dframe.columns:
-                dframe["PORO (net)"] = dframe["PORV"] / dframe["NET"]
+                dframe["PORO_NET"] = dframe["PORV"] / dframe["NET"]
             dframe["PORO"] = dframe["PORV"] / dframe["BULK"]
         if "SW" in properties:
             dframe["SW"] = 1 - (dframe["HCPV"] / dframe["PORV"])
@@ -318,59 +285,6 @@ class InplaceVolumesModel:
                 dframe["BG"] = "NA"
         return dframe
 
-    def _prepare_parameter_data(
-        self, parameter_table: pd.DataFrame, drop_constants: bool
-    ) -> pd.DataFrame:
-        """
-        Different data preparations on the parameters, before storing them as an attribute.
-        Option to drop parameters with constant values. Prefixes on parameters from GEN_KW
-        are removed, in addition parameters with LOG distribution will be kept while the
-        other is dropped.
-        """
-
-        parameter_table = parameter_table.reset_index(drop=True)
-
-        if drop_constants:
-            constant_params = [
-                param
-                for param in [
-                    x for x in parameter_table.columns if x not in self.SENS_COLUMNS
-                ]
-                if len(parameter_table[param].unique()) == 1
-            ]
-            parameter_table = parameter_table.drop(columns=constant_params)
-
-        # Keep only LOG parameters
-        log_params = [
-            param.replace("LOG10_", "")
-            for param in [
-                x for x in parameter_table.columns if x not in self.SENS_COLUMNS
-            ]
-            if param.startswith("LOG10_")
-        ]
-        parameter_table = parameter_table.drop(columns=log_params)
-
-        parameter_table = parameter_table.rename(
-            columns={
-                col: f"{col} (log)"
-                for col in parameter_table.columns
-                if col.startswith("LOG10_")
-            }
-        )
-        # Remove prefix on parameter name added by GEN_KW
-        parameter_table = parameter_table.rename(
-            columns={
-                col: (col.split(":", 1)[1])
-                for col in parameter_table.columns
-                if (":" in col and col not in self.SENS_COLUMNS)
-            }
-        )
-
-        # Drop columns if duplicate names
-        parameter_table = parameter_table.loc[:, ~parameter_table.columns.duplicated()]
-
-        return parameter_table
-
 
 def filter_df(dframe: pd.DataFrame, filters: dict) -> pd.DataFrame:
     """
@@ -383,15 +297,25 @@ def filter_df(dframe: pd.DataFrame, filters: dict) -> pd.DataFrame:
 
 
 def extract_volumes(
-    ensemble_set_model: EnsembleSetModel, volfolder: str, volfiles: Dict[str, Any]
+    ensemble_set_model: EnsembleSetModel,
+    volfolder: str,
+    volfiles: Dict[str, Any],
 ) -> pd.DataFrame:
     """Aggregates volumetric files from an FMU ensemble.
     Files must be stored on standardized csv format.
     """
-
     dfs = []
-    for volname, volfile in volfiles.items():
-        df = ensemble_set_model.load_csv(Path(volfolder) / volfile)
+    for volname, files in volfiles.items():
+        if isinstance(files, list):
+            volframes = [
+                ensemble_set_model.load_csv(Path(volfolder) / volfile)
+                for volfile in files
+            ]
+            df = merge_csv_files(volframes)
+        elif isinstance(files, str):
+            df = ensemble_set_model.load_csv(Path(volfolder) / files)
+        else:
+            raise ValueError("Wrong format of volfile value argument!")
         df["SOURCE"] = volname
         dfs.append(df)
 
@@ -401,3 +325,14 @@ def extract_volumes(
             f"Ensure that the files are present in relative folder {volfolder}"
         )
     return pd.concat(dfs)
+
+
+def merge_csv_files(volframes: List[pd.DataFrame]) -> pd.DataFrame:
+    """Merge csv files on common columns"""
+    common_columns = list(
+        set.intersection(*[set(frame.columns) for frame in volframes])
+    )
+    merged_dframe = pd.DataFrame(columns=common_columns)
+    for frame in volframes:
+        merged_dframe = pd.merge(merged_dframe, frame, on=common_columns, how="outer")
+    return merged_dframe
