@@ -1,14 +1,13 @@
-from typing import List, Tuple, Callable, Optional, Any
-from pathlib import Path
-import warnings
-import json
 import io
+import warnings
+from pathlib import Path
+from typing import Any, Callable, Dict, List, Optional, Tuple
 
 import numpy as np
 import pandas as pd
 import xtgeo
-from webviz_config.webviz_store import webvizstore
 from webviz_config.common_cache import CACHE
+from webviz_config.webviz_store import webvizstore
 
 
 class SurfaceSetModel:
@@ -17,6 +16,11 @@ class SurfaceSetModel:
     def __init__(self, surface_table: pd.DataFrame):
         self._surface_table = surface_table
 
+    @property
+    def realizations(self) -> list:
+        """Returns surface attributes"""
+        return sorted(list(self._surface_table["REAL"].unique()))
+
     @property
     def attributes(self) -> list:
         """Returns surface attributes"""
@@ -38,6 +42,26 @@ class SurfaceSetModel:
             ].unique()
         )
 
+    def get_realization_surfaces(
+        self,
+        name: str,
+        attribute: str,
+        realizations: List[int],
+        date: Optional[str] = None,
+    ) -> List[Dict[str, Any]]:
+        return [
+            {
+                "REAL": realization,
+                "surface": self.get_realization_surface(
+                    name=name,
+                    attribute=attribute,
+                    realization=int(realization),
+                    date=date,
+                ),
+            }
+            for realization in realizations
+        ]
+
     def get_realization_surface(
         self, name: str, attribute: str, realization: int, date: Optional[str] = None
     ) -> xtgeo.RegularSurface:
@@ -50,14 +74,16 @@ class SurfaceSetModel:
             column_values.append(date)
 
         df = self._filter_surface_table(
-            name=name, attribute=attribute, date=date, realizations=[realization]
+            name=name, attribute=attribute, date=date, realizations=[int(realization)]
         )
         if len(df.index) == 0:
             warnings.warn(
                 f"No surface found for name: {name}, attribute: {attribute}, date: {date}, "
                 f"realization: {realization}"
             )
-            return xtgeo.RegularSurface()
+            return xtgeo.RegularSurface(
+                ncol=1, nrow=1, xinc=1, yinc=1
+            )  # 1's as input is required
         if len(df.index) > 1:
             warnings.warn(
                 f"Multiple surfaces found for name: {name}, attribute: {attribute}, date: {date}, "
@@ -102,9 +128,18 @@ class SurfaceSetModel:
         df = self._filter_surface_table(
             name=name, attribute=attribute, date=date, realizations=realizations
         )
-        return surface_from_json(
-            json.load(save_statistical_surface(sorted(list(df["path"])), calculation))
-        )
+        # When portable check if the surface has been stored
+        # if not calculate
+        try:
+            surface_stream = save_statistical_surface(
+                sorted(list(df["path"])), calculation
+            )
+        except OSError:
+            surface_stream = save_statistical_surface_no_store(
+                sorted(list(df["path"])), calculation
+            )
+
+        return xtgeo.surface_from_file(surface_stream, fformat="irap_binary")
 
     def webviz_store_statistical_calculation(
         self,
@@ -151,6 +186,24 @@ class SurfaceSetModel:
             [{"runpath": path} for path in list(self._surface_table["path"])],
         )
 
+    @property
+    def first_surface_geometry(self) -> Dict:
+        surface = xtgeo.surface_from_file(
+            get_stored_surface_path(self._surface_table.iloc[0]["path"])
+        )
+        return {
+            "xmin": surface.xmin,
+            "xmax": surface.xmax,
+            "ymin": surface.ymin,
+            "ymax": surface.ymax,
+            "xori": surface.xori,
+            "yori": surface.yori,
+            "ncol": surface.ncol,
+            "nrow": surface.nrow,
+            "xinc": surface.xinc,
+            "yinc": surface.yinc,
+        }
+
 
 @webvizstore
 def get_stored_surface_path(runpath: Path) -> Path:
@@ -158,12 +211,16 @@ def get_stored_surface_path(runpath: Path) -> Path:
     return Path(runpath)
 
 
-@webvizstore
-def save_statistical_surface(fns: List[str], calculation: str) -> io.BytesIO:
+def save_statistical_surface_no_store(
+    fns: List[str], calculation: Optional[str] = "Mean"
+) -> io.BytesIO:
     """Wrapper function to store a calculated surface as BytesIO"""
-    surfaces = xtgeo.Surfaces(fns)
+
+    surfaces = xtgeo.Surfaces([get_stored_surface_path(fn) for fn in fns])
     if len(surfaces.surfaces) == 0:
-        surface = xtgeo.RegularSurface()
+        surface = xtgeo.RegularSurface(
+            ncol=1, nrow=1, xinc=1, yinc=1
+        )  # 1's as input is required
     elif calculation in ["Mean", "StdDev", "Min", "Max", "P10", "P90"]:
         # Suppress numpy warnings when surfaces have undefined z-values
         with warnings.catch_warnings():
@@ -172,8 +229,36 @@ def save_statistical_surface(fns: List[str], calculation: str) -> io.BytesIO:
             warnings.filterwarnings("ignore", "Degrees of freedom <= 0 for slice")
             surface = get_statistical_surface(surfaces, calculation)
     else:
-        surface = xtgeo.RegularSurface()
-    return io.BytesIO(surface_to_json(surface).encode())
+        surface = xtgeo.RegularSurface(
+            ncol=1, nrow=1, xinc=1, yinc=1
+        )  # 1's as input is required
+    stream = io.BytesIO()
+    surface.to_file(stream, fformat="irap_binary")
+    return stream
+
+
+@webvizstore
+def save_statistical_surface(fns: List[str], calculation: str) -> io.BytesIO:
+    """Wrapper function to store a calculated surface as BytesIO"""
+    surfaces = xtgeo.Surfaces(fns)
+    if len(surfaces.surfaces) == 0:
+        surface = xtgeo.RegularSurface(
+            ncol=1, nrow=1, xinc=1, yinc=1
+        )  # 1's as input is required
+    elif calculation in ["Mean", "StdDev", "Min", "Max", "P10", "P90"]:
+        # Suppress numpy warnings when surfaces have undefined z-values
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore", "All-NaN slice encountered")
+            warnings.filterwarnings("ignore", "Mean of empty slice")
+            warnings.filterwarnings("ignore", "Degrees of freedom <= 0 for slice")
+            surface = get_statistical_surface(surfaces, calculation)
+    else:
+        surface = xtgeo.RegularSurface(
+            ncol=1, nrow=1, xinc=1, yinc=1
+        )  # 1's as input is required
+    stream = io.BytesIO()
+    surface.to_file(stream, fformat="irap_binary")
+    return stream
 
 
 # pylint: disable=too-many-return-statements
@@ -193,27 +278,6 @@ def get_statistical_surface(
         return surfaces.apply(np.nanpercentile, 10, axis=0)
     if calculation == "P90":
         return surfaces.apply(np.nanpercentile, 90, axis=0)
-    return xtgeo.RegularSurface()
-
-
-def surface_to_json(surface: xtgeo.RegularSurface) -> str:
-    """Returns a json represention of a Xtgeo surface instance"""
-    return json.dumps(
-        {
-            "ncol": surface.ncol,
-            "nrow": surface.nrow,
-            "xori": surface.xori,
-            "yori": surface.yori,
-            "rotation": surface.rotation,
-            "xinc": surface.xinc,
-            "yinc": surface.yinc,
-            "values": surface.values.copy().filled(np.nan).tolist(),
-        }
-    )
-
-
-def surface_from_json(surfaceobj: dict) -> xtgeo.RegularSurface:
-    """Returns a Xtgeo surface instance from a json surface representation"""
-    surface = xtgeo.RegularSurface(**surfaceobj)
-    surface.values = surfaceobj["values"]
-    return surface
+    return xtgeo.RegularSurface(
+        ncol=1, nrow=1, xinc=1, yinc=1
+    )  # 1's as input is required
