@@ -1,20 +1,16 @@
-from typing import Union, List, Dict, Optional, Tuple
-from datetime import datetime
-from uuid import uuid4
 import json
+from datetime import datetime
+from typing import Dict, List, Optional, Tuple, Union
+from uuid import uuid4
 
-import yaml
 import numpy as np
 import pandas as pd
-import dash
-from dash.dependencies import Input, Output, State
+import yaml
+from dash import Dash, Input, Output, State, callback_context, dcc, html
 from dash.exceptions import PreventUpdate
-import dash_html_components as html
-import dash_core_components as dcc
 
 
 class SurfaceSelector:
-    # pylint: disable=too-many-instance-attributes,too-many-statements
     """### Surface Selector
 
     Creates a widget to select surfaces from a yaml configuration file or dictionary, and
@@ -42,7 +38,7 @@ class SurfaceSelector:
             - somedate"""
 
     def __init__(
-        self, app: dash.Dash, config: Union[str, dict], ensembles: pd.DataFrame
+        self, app: Dash, config: Union[str, dict], ensembles: pd.DataFrame
     ) -> None:
 
         self._configuration = self.read_config(config)
@@ -207,8 +203,7 @@ class SurfaceSelector:
             ]
         )
 
-    def set_callbacks(self, app: dash.Dash) -> None:
-        # pylint: disable=inconsistent-return-statements
+    def set_callbacks(self, app: Dash) -> None:
         @app.callback(
             Output(self.attr_id, "value"),
             [
@@ -220,7 +215,7 @@ class SurfaceSelector:
         def _update_attr(
             _n_prev: Optional[int], _n_next: Optional[int], current_value: str
         ) -> str:
-            ctx = dash.callback_context.triggered
+            ctx = callback_context.triggered
             if ctx is None or not current_value:
                 raise PreventUpdate
             if not ctx[0]["value"]:
@@ -251,7 +246,7 @@ class SurfaceSelector:
             _n_next: Optional[int],
             current_value: str,
         ) -> Tuple[Optional[List[Dict[str, str]]], Optional[str], Dict[str, str]]:
-            ctx = dash.callback_context.triggered
+            ctx = callback_context.triggered
             if ctx is None:
                 raise PreventUpdate
             names = self._names_in_attr(attr)
@@ -287,7 +282,7 @@ class SurfaceSelector:
             _n_next: Optional[int],
             current_value: str,
         ) -> Tuple[List[Dict[str, str]], Optional[str], Dict[str, str]]:
-            ctx = dash.callback_context.triggered
+            ctx = callback_context.triggered
 
             if ctx is None:
                 raise PreventUpdate
@@ -302,7 +297,13 @@ class SurfaceSelector:
             elif callback == f"{self.date_id_btn_next}.n_clicks":
                 value = next_value(current_value, dates)
             else:
-                value = current_value if current_value in dates else dates[0]
+                value = (
+                    current_value
+                    if current_value
+                    in dates  # pylint: disable=unsupported-membership-test
+                    else dates[0]  # pylint: disable=unsubscriptable-object
+                )
+            # pylint: disable=not-an-iterable
             options = [{"label": format_date(date), "value": date} for date in dates]
             return options, value, {}
 
