@@ -1,8 +1,7 @@
-import xtgeo
-import pandas as pd
 import numpy as np
+import pandas as pd
 import plotly.graph_objects as go
-
+import xtgeo
 from webviz_config.common_cache import CACHE
 
 
@@ -308,8 +307,8 @@ class HuvXsection:
                         point=(row["X_UTME"], row["Y_UTMN"])
                     )
                     data["Surface name"].append(surface_name)
-                    data["TVD [m]"].append("%.2f" % row["Z_TVDSS"])
-                    data["TVD SD [m]"].append("%.2f" % depth_uncertainty)
+                    data["TVD [m]"].append(f"{row['Z_TVDSS']:.2f}")
+                    data["TVD SD [m]"].append(f"{depth_uncertainty:.2f}")
                     data["Direction"].append(row["DIRECTION"])
         return pd.DataFrame(data=data)
 
