@@ -1,14 +1,10 @@
 from typing import Callable
 
-import dash_html_components as html
 import webviz_core_components as wcc
+from dash import html
 
-from .selector_view import (
-    ensemble_selector,
-    filter_parameter,
-    sortby_selector,
-)
 from ..models import ParametersModel
+from .selector_view import ensemble_selector, filter_parameter, sortby_selector
 
 
 def selector_view(get_uuid: Callable, parametermodel: ParametersModel) -> html.Div:
@@ -55,14 +51,14 @@ def parameter_qc_view(
     get_uuid: Callable, parametermodel: ParametersModel
 ) -> wcc.FlexBox:
     return wcc.FlexBox(
-        style={"margin": "20px"},
         children=[
             wcc.FlexColumn(
                 wcc.Frame(
+                    style={"height": "80vh"},
                     children=selector_view(
                         get_uuid=get_uuid, parametermodel=parametermodel
                     ),
-                )
+                ),
             ),
             wcc.FlexColumn(
                 flex=4,
@@ -84,7 +80,8 @@ def parameter_qc_view(
                             value="distribution",
                         ),
                         html.Div(
-                            style={"height": "75vh"}, id=get_uuid("property-qc-wrapper")
+                            style={"height": "75vh", "margin-top": "20px"},
+                            id=get_uuid("property-qc-wrapper"),
                         ),
                     ],
                 ),
