@@ -1,20 +1,20 @@
 from pathlib import Path
 
 import pandas as pd
-from plotly.subplots import make_subplots
-from dash.dependencies import Input, Output
-import dash_core_components as dcc
 import webviz_core_components as wcc
-from webviz_config.webviz_store import webvizstore
+from dash import Input, Output, dcc
+from plotly.subplots import make_subplots
+from webviz_config import WebvizPluginABC, WebvizSettings
 from webviz_config.common_cache import CACHE
-from webviz_config import WebvizPluginABC
-from webviz_config import WebvizSettings
 from webviz_config.utils import calculate_slider_step
+from webviz_config.webviz_store import webvizstore
 
-from webviz_subsurface._models import EnsembleSetModel
-from webviz_subsurface._models import caching_ensemble_set_model_factory
-from webviz_subsurface._datainput.fmu_input import load_parameters, load_csv
 import webviz_subsurface._utils.parameter_response as parresp
+from webviz_subsurface._datainput.fmu_input import load_csv, load_parameters
+from webviz_subsurface._models import (
+    EnsembleSetModel,
+    caching_ensemble_set_model_factory,
+)
 
 
 class ParameterResponseCorrelation(WebvizPluginABC):
