@@ -1,46 +1,59 @@
 # pylint: disable=too-many-lines
-from typing import Optional, List, Tuple, Callable, Union, Any
-from pathlib import Path
 import fnmatch
-import warnings
 import json
+import warnings
 from copy import deepcopy
+from pathlib import Path
+from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
-import yaml
 import numpy as np
 import pandas as pd
-import dash
-from dash_table import DataTable
-import dash_html_components as html
-import dash_core_components as dcc
 import webviz_core_components as wcc
-from dash.dependencies import Input, Output, State, ALL
+import yaml
+from dash import (
+    ALL,
+    Dash,
+    Input,
+    Output,
+    State,
+    callback_context,
+    dash_table,
+    dcc,
+    html,
+)
 from dash.exceptions import PreventUpdate
+from webviz_config import WebvizConfigTheme, WebvizPluginABC, WebvizSettings
 from webviz_config.common_cache import CACHE
 from webviz_config.webviz_store import webvizstore
-from webviz_config import WebvizPluginABC
-from webviz_config import WebvizConfigTheme
-from webviz_config import WebvizSettings
 
-from webviz_subsurface._models import EnsembleSetModel
-from webviz_subsurface._models import caching_ensemble_set_model_factory
+from webviz_subsurface._models import (
+    EnsembleSetModel,
+    caching_ensemble_set_model_factory,
+)
+
+from .._abbreviations.number_formatting import table_statistics_base
 from .._abbreviations.reservoir_simulation import (
-    simulation_vector_base,
-    simulation_vector_description,
+    historical_vector,
     simulation_region_vector_breakdown,
     simulation_region_vector_recompose,
     simulation_unit_reformat,
-    historical_vector,
+    simulation_vector_base,
+    simulation_vector_description,
+)
+from .._utils.fanchart_plotting import (
+    FanchartData,
+    FreeLineData,
+    LowHighData,
+    MinMaxData,
+    get_fanchart_traces,
 )
-from .._abbreviations.number_formatting import table_statistics_base
-from .._utils.unique_theming import unique_colors
 from .._utils.simulation_timeseries import (
-    set_simulation_line_shape_fallback,
     get_simulation_line_shape,
+    set_simulation_line_shape_fallback,
 )
-from .._utils.colors import hex_to_rgba
+from .._utils.unique_theming import unique_colors
+
 
-# pylint: disable=too-many-instance-attributes
 class ReservoirSimulationTimeSeriesRegional(WebvizPluginABC):
     """Aggregates and visualizes regional time series data from simulation ensembles. That
 is: cumulatives, rates and inplace volumes. Allows human friendly filter names, e.g. regions,
@@ -116,10 +129,10 @@ folder, to avoid risk of not extracting the right data.
     TABLE_STATISTICS: List[Tuple[str, dict]] = [("Group", {})] + table_statistics_base()
     ENSEMBLE_COLUMNS = ["REAL", "ENSEMBLE", "DATE"]
 
-    # pylint: disable=dangerous-default-value, too-many-arguments
+    # pylint: disable=too-many-arguments
     def __init__(
         self,
-        app: dash.Dash,
+        app: Dash,
         webviz_settings: WebvizSettings,
         ensembles: list,
         fipfile: Path = None,
@@ -499,7 +512,7 @@ folder, to avoid risk of not extracting the right data.
         )
 
     # pylint: disable=too-many-statements
-    def set_callbacks(self, app: dash.Dash) -> None:
+    def set_callbacks(self, app: Dash) -> None:
         @app.callback(
             [
                 Output(self.uuid("filters"), "children"),
@@ -620,7 +633,7 @@ folder, to avoid risk of not extracting the right data.
             # TODO(Sigurd) Currently giving up on deciding on the return type for
             # _render_charts() above. Some of the mypy errors indicate that there
             # are some errors in the structure of the return values of this function
-            inputs = dash.callback_context.inputs
+            inputs = callback_context.inputs
             date = json.loads(inputs.pop(f"{self.uuid('date')}.data"))
             ensembles = inputs.pop(self.selectors_context_string("ensemble", "value"))
             ensembles = ensembles if isinstance(ensembles, list) else [ensembles]
@@ -734,7 +747,7 @@ folder, to avoid risk of not extracting the right data.
                     "title": make_title(self.smry_meta, ref_vector, vector, mode),
                     "showgrid": False,
                 },
-                "xaxis": {"showgrid": False},
+                "xaxis": {"showgrid": False, "uirevision": "locked"},
                 "height": 450,
             }
             if mode == "rec":
@@ -974,7 +987,7 @@ def render_single_date_graph(
 
 def render_table(
     stat_df: pd.DataFrame, mode: str, groupby: str, date: str
-) -> DataTable:
+) -> dash_table.DataTable:
     columns = []
     if mode == "agg":
         columns = [col[0] for col in stat_df.columns if col[0].startswith("AGG_")]
@@ -1036,7 +1049,7 @@ def render_table(
             except KeyError:
                 pass
     return (
-        DataTable(
+        dash_table.DataTable(
             sort_action="native",
             filter_action="native",
             page_action="native",
@@ -1114,7 +1127,7 @@ def filter_and_aggregate_vectors(
 @CACHE.memoize(timeout=CACHE.TIMEOUT)
 def get_nodes(groupby: str, fipdesc: pd.DataFrame, fip: str, filters: dict) -> dict:
     df = fipdesc[fipdesc["FIP"] == fip]
-    nodes: dict = dict()
+    nodes: dict = {}
     for node, dfn in df.groupby("NODE"):
         node_inc = True
         node_subgroups = []
@@ -1276,9 +1289,9 @@ def add_statistic_traces(
         if groupby == "ENSEMBLE":
             for ens in ensembles:
                 traces.extend(
-                    add_fanchart_traces(
+                    _get_fanchart_traces(
                         stat_df=stat_df[stat_df["ENSEMBLE"] == ens],
-                        col=col,
+                        column=col,
                         legend_group=ens,
                         color=groupby_color[groupby][ens],
                         line_shape=line_shape,
@@ -1286,9 +1299,9 @@ def add_statistic_traces(
                 )
         else:
             traces.extend(
-                add_fanchart_traces(
+                _get_fanchart_traces(
                     stat_df=stat_df,
-                    col=col,
+                    column=col,
                     legend_group=col.split("_filtered_on_")[-1],
                     color=groupby_color[groupby][col.split("_filtered_on_")[-1]],
                     line_shape=line_shape,
@@ -1297,72 +1310,37 @@ def add_statistic_traces(
     return traces
 
 
-def add_fanchart_traces(
-    stat_df: pd.DataFrame, col: str, legend_group: str, color: str, line_shape: str
-) -> List[dict]:
+def _get_fanchart_traces(
+    stat_df: pd.DataFrame, column: str, legend_group: str, color: str, line_shape: str
+) -> List[Dict[str, Any]]:
     """Renders a fanchart"""
-    fill_color = hex_to_rgba(color, 0.3)
-    line_color = hex_to_rgba(color, 1)
-    return [
-        {
-            "name": legend_group,
-            "hovertext": f"Maximum {legend_group}",
-            "x": stat_df["DATE"],
-            "y": stat_df[col]["nanmax"],
-            "mode": "lines",
-            "line": {"width": 0, "color": line_color, "shape": line_shape},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-        {
-            "name": legend_group,
-            "hovertext": f"P90 {legend_group}",
-            "x": stat_df["DATE"],
-            "y": stat_df[col]["p90"],
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"width": 0, "color": line_color, "shape": line_shape},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-        {
-            "name": legend_group,
-            "hovertext": f"Mean {legend_group}",
-            "x": stat_df["DATE"],
-            "y": stat_df[col]["nanmean"],
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"color": line_color, "shape": line_shape},
-            "legendgroup": legend_group,
-            "showlegend": True,
-        },
-        {
-            "name": legend_group,
-            "hovertext": f"P10 {legend_group}",
-            "x": stat_df["DATE"],
-            "y": stat_df[col]["p10"],
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"width": 0, "color": line_color, "shape": line_shape},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-        {
-            "name": legend_group,
-            "hovertext": f"Minimum {legend_group}",
-            "x": stat_df["DATE"],
-            "y": stat_df[col]["nanmin"],
-            "mode": "lines",
-            "fill": "tonexty",
-            "fillcolor": fill_color,
-            "line": {"width": 0, "color": line_color, "shape": line_shape},
-            "legendgroup": legend_group,
-            "showlegend": False,
-        },
-    ]
+
+    x = stat_df["DATE"].tolist()
+
+    data = FanchartData(
+        samples=x,
+        low_high=LowHighData(
+            low_data=stat_df[column]["p90"].values,
+            low_name="P90",
+            high_data=stat_df[column]["p10"].values,
+            high_name="P10",
+        ),
+        minimum_maximum=MinMaxData(
+            minimum=stat_df[column]["nanmin"].values,
+            maximum=stat_df[column]["nanmax"].values,
+        ),
+        free_line=FreeLineData("Mean", stat_df[column]["nanmean"].values),
+    )
+
+    hovertemplate = f"{legend_group}"
+
+    return get_fanchart_traces(
+        data=data,
+        color=color,
+        legend_group=legend_group,
+        line_shape=line_shape,
+        hovertext=hovertemplate,
+    )
 
 
 def get_fip_array_nodes(fip: str, smry_cols: list) -> List[int]:
