@@ -1,26 +1,24 @@
-from typing import Optional, List, Dict, Tuple, Callable, Any, Union
 from pathlib import Path
+from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
-import dash
 import numpy as np
 import pandas as pd
-import dash_html_components as html
-from dash.exceptions import PreventUpdate
-from dash.dependencies import Input, Output, State
 import webviz_core_components as wcc
-from webviz_config import WebvizPluginABC
-from webviz_config import WebvizSettings
+from dash import Dash, Input, Output, State, html
+from dash.exceptions import PreventUpdate
+from webviz_config import WebvizPluginABC, WebvizSettings
 from webviz_config.common_cache import CACHE
 from webviz_config.webviz_store import webvizstore
 
-from webviz_subsurface._utils.unique_theming import unique_colors
 from webviz_subsurface._datainput.fmu_input import load_csv
-from ._processing import filter_frame
+from webviz_subsurface._utils.unique_theming import unique_colors
+
+from ._crossplot_figure import update_crossplot
+from ._errorplot_figure import update_errorplot
 from ._formation_figure import FormationFigure
 from ._map_figure import MapFigure
 from ._misfit_figure import update_misfit_plot
-from ._crossplot_figure import update_crossplot
-from ._errorplot_figure import update_errorplot
+from ._processing import filter_frame
 
 
 class RftPlotter(WebvizPluginABC):
@@ -103,7 +101,7 @@ forward_models.html?highlight=gendata_rft#MERGE_RFT_ERTOBS).
     # pylint: disable=too-many-arguments
     def __init__(
         self,
-        app: dash.Dash,
+        app: Dash,
         webviz_settings: WebvizSettings,
         csvfile_rft: Path = None,
         csvfile_rft_ert: Path = None,
@@ -432,9 +430,7 @@ forward_models.html?highlight=gendata_rft#MERGE_RFT_ERTOBS).
             ],
         )
 
-    def filter_layout(
-        self, tab: str
-    ) -> List[dash.development.base_component.Component]:
+    def filter_layout(self, tab: str) -> List[wcc.Selectors]:
         """Layout for shared filters"""
         return wcc.Selectors(
             label="Selectors",
@@ -633,7 +629,7 @@ forward_models.html?highlight=gendata_rft#MERGE_RFT_ERTOBS).
             ],
         )
 
-    def set_callbacks(self, app: dash.Dash) -> None:
+    def set_callbacks(self, app: Dash) -> None:
         @app.callback(
             Output(self.uuid("well"), "value"),
             [
