@@ -1,12 +1,11 @@
-from typing import Optional, Callable
+from typing import Callable, Optional
 
-import dash
+from dash import MATCH, Dash, Input, Output, State
 from dash.exceptions import PreventUpdate
-from dash.dependencies import Input, Output, State, MATCH
 
 
 def open_modals(
-    app: dash.Dash,
+    app: Dash,
     get_uuid: Callable,
 ) -> None:
     @app.callback(
