@@ -1,9 +1,8 @@
-from typing import List, Callable, Dict, Optional
+from typing import Callable, Dict, List, Optional
 
-import dash_core_components as dcc
 import dash_bootstrap_components as dbc
-import dash_html_components as html
 import webviz_core_components as wcc
+from dash import dcc, html
 
 from .modal import open_modal_layout
 from .uncertainty_table import uncertainty_table_btn
