@@ -1,6 +1,5 @@
-import dash_html_components as html
-import dash_table
 import webviz_core_components as wcc
+from dash import dash_table, html
 
 
 def uncertainty_table_layout(
